@@ -1,4 +1,4 @@
-from upt.utils import Utils, Driver
+from upt.utils import Utils, Driver, By
 
 
 class Parser:
@@ -9,7 +9,7 @@ class Parser:
     @staticmethod
     def parse(args: list):
         if len(args) != 2:
-            raise Exception("arguments are not correct")
+            raise Exception("Arguments are not correct")
 
         tp = Parser.TYPE.get(args[0])
         if tp is None:
@@ -17,7 +17,8 @@ class Parser:
 
         driver = Driver()
         url = f"http://quera.ir/problemset/{tp}/{args[1]}/"
-        Utils.load_url(driver, url)
+        driver.get(url)
+        Utils.wait_until(driver, By.CSS_SELECTOR, "pre")
 
         sample = Utils.get_sample(driver)
         result = Utils.even_odd(sample)
