@@ -1,15 +1,16 @@
-from upt.utils import Utils, Driver
+from upt.utils import Utils, Driver, By
 
 
 class Parser:
     @staticmethod
     def parse(args: list):
         if len(args) != 1:
-            raise Exception("arguments are not correct")
+            raise Exception("Arguments are not correct")
 
         driver = Driver()
         url = f"http://www.spoj.com/problems/{args[0]}/"
-        Utils.load_url(driver, url)
+        driver.get(url)
+        Utils.wait_until(driver, By.CSS_SELECTOR, "pre")
 
         sample = Utils.get_sample(driver)
         result = Utils.tag_sens(sample)
